@@ -102,13 +102,13 @@ var NAVTREEINDEX =
 [
 "annotated.html",
 "core_8h.html#a3c4c5529b9bb6c9188053bdf1604c2e0",
-"global_8h.html#a48ade1ac8c560225b6d54dedbc48836a",
-"impl-node_8c.html#a332223aa26f5d6c79181cf63e51b2bf6",
-"link_8h.html#a7859f6eb040fead1673d0214b83b445b",
-"permission_8h.html#a77df16320c3bb338666f55b2b21e6e47",
-"stream_8h.html#a55c1224289e488e27f8d3b6e58abcd08",
-"structpw__factory__info.html",
-"structpw__protocol__implementaton.html#a5dbc29661309ba54e93539eae72ba595"
+"global_8h.html#a3c30e6a36a12ab02e97c7a0014d578d0",
+"impl-node_8c.html#a0c09f345941b97bd6bc796ee014214f0",
+"link_8h.html#a481b4d0b9cd49478fd13dc8934478840",
+"pages.html",
+"stream_8h.html#a058907c2dffbb8fb5ede8a53d7604106a2912e7520b8eb0aa5e4a5ca275f10d3b",
+"structpw__device__methods.html",
+"structpw__protocol__client.html#a020b1da93f4f58c485ff64da4a5ac655"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
