@@ -9,11 +9,11 @@ var structstream =
     [ "data", "structstream.html#a53964295d5a2b27dd8a2eead24f3dfd6", null ],
     [ "dequeued", "structstream.html#a369dbaa5cdda9aad66fc4ee6af6cc911", null ],
     [ "direction", "structstream.html#a386c312c7ee7ec6ad015165614514b6f", null ],
+    [ "disconnect_core", "structstream.html#a234356f9ddb74bc10ccdf7f8abf439e8", null ],
     [ "disconnecting", "structstream.html#a5e861c5f495c43750eda66e177a1b9c3", null ],
     [ "drained", "structstream.html#a0b67dcf51974d8cf6b73151658d42be3", null ],
     [ "draining", "structstream.html#a4277cb8aee76d493dd3fe7c5292b9d19", null ],
     [ "flags", "structstream.html#a41be007c6de999aff0def3e6bb0e1652", null ],
-    [ "free_proxy", "structstream.html#aa13120de0c201a0ee479aaad124a3f47", null ],
     [ "hooks", "structstream.html#af472f42f40a7c7bb801fe844e228aed6", null ],
     [ "impl_node", "structstream.html#a33ef55c30dba3f533ce558a3a8918d6c", null ],
     [ "io", "structstream.html#ac744f31dcf0b62846bd67d2a525834f7", null ],
